@@ -3,9 +3,9 @@ package Data::Dumper::Compact;
 use List::Util qw(sum);
 use Scalar::Util qw(blessed reftype);
 use Data::Dumper ();
-use Mu; #::Tiny;
+use Mu::Tiny;
 
-our $VERSION = '0.005000';
+our $VERSION = '0.005001';
 $VERSION =~ tr/_//d;
 
 sub import {
